from distutils.core import setup
setup(
  name = 'xy_brain',
  packages = ['xy_brain'],
  version = '3.0.0',
  description = 'Get The Brain Test',
  long_description='Get The brain test',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  keywords = ['pip3', 'python3','python','brain'],
  license='MIT',
)
